@@ -3,12 +3,19 @@ import cooler
 import numpy as np
 from src import getStripe
 
-def getScore(cool, coordinates,norm,header,numcores,out,mask='0'):
-    if header:
-        header = 0
+def getScore(cool, coordinates,norm,numcores,out,mask='0'):
+    # Just open without header
+    table = pd.read_csv(coordinates,header=None,sep='\t')
+    # test
+    el = table.iloc[0]
+    el1 = el[1]
+    el2 = el[2]
+
+    if type(el1) != str and type(el2) != str :
+        pass
     else:
-        header = None
-    table = pd.read_csv(coordinates,header=header,sep='\t')
+        table = pd.read_csv(coordinates,header=0, sep='\t')
+
     table.columns=['chr','pos1','pos2','chr2','pos3','pos4']+table.columns[6:].tolist()
 
     core = numcores
@@ -38,11 +45,11 @@ def getScore(cool, coordinates,norm,header,numcores,out,mask='0'):
     resol = Lib._info['bin-size']
     obj = getStripe.getStripe(unbalLib, resol, 10, 8, 2.5, all_chromnames, chromnames, all_chromsizes, chromsizes,core)
     EV = getStripe.getStripe.mpmean(obj)
-    bgleft, bgright = getStripe.getStripe.nulldist(obj)
-    pval = getStripe.getStripe.pvalue(obj, bgleft, bgright, table)
+    bgleft_up, bgright_up, bgleft_down, bgright_down = getStripe.getStripe.nulldist(obj)
+    pval = getStripe.getStripe.pvalue(obj, bgleft_up, bgright_up, bgleft_down, bgright_down, table)
     table.insert(table.shape[1],'pvalue_added',pval,True)
     MEAN, SUM = getStripe.getStripe.getMean(obj,table)
-    s,MEANOE,TOTALOE = getStripe.getStripe.scoringstripes(obj, table, EV, mask)
+    s,MEANOE,TOTALOE = obj.scoringstripes(table, EV, mask)
     table.insert(table.shape[1],'Stripiness_added',s,True)
     table.insert(table.shape[1], "O_Mean_added", MEAN, True)
     table.insert(table.shape[1], "O_Sum_added", SUM, True)
